import 'package:http/http.dart';
import 'package:rook_users/src/data/server/helper/get_error_from_response.dart';
import 'package:rook_users/src/datasource/status/data_source_status_sv_model.dart';

/// Helper class to send users requests.
class DataSourceStatusApiService {
  final Client _client = Client();

  final String _baseUrl;
  final String _authorization;

  DataSourceStatusApiService({
    required String baseUrl,
    required String authorization,
  })  : _baseUrl = baseUrl,
        _authorization = authorization;

  String get urlPostFix => '/api/v1';

  /// Sends json string to server.
  ///
  /// This function builds a generic request and decodes the returned bytes.
  ///
  /// Using http package's built in patch function will result in 'Content-Type' header being locked to 'application/json; charset=utf-8'.
  Future<Response> _patch(Uri uri, String json) async {
    final request = Request('PATCH', uri);
    request.body = json;
    request.headers['Accept'] = 'application/json';
    request.headers['Content-Type'] = 'application/json';
    request.headers['Authorization'] = _authorization;

    final streamedResponse = await _client.send(request).timeout(tenSeconds);

    return Response.fromStream(streamedResponse);
  }

  Future<void> changeStatus(String userID, DataSourceStatusSvModel body) async {
    final uri =
        Uri.https(_baseUrl, '$urlPostFix/user_id/$userID/change-status');

    final response = await _patch(uri, body.toJson());

    if (response.statusCode == 200) {
      return;
    } else {
      throw Exception(getErrorFromResponse(response));
    }
  }
}

const tenSeconds = Duration(seconds: 10);
